import { defineStore } from 'pinia';
const stores = {};
const createProxyStore = (useStore) => {
    return new Proxy({}, {
        get: (_, key) => {
            const store = useStore();
            return store[key];
        },
        set: (_, key, value) => {
            const store = useStore();
            store[key] = value;
            return true;
        },
    });
};
const createProxyPermStore = (name) => {
    return new Proxy({}, {
        get: (_, key) => {
            const json = localStorage.getItem(name);
            if (!json)
                return undefined;
            const object = JSON.parse(json);
            return object[key];
        },
        set: (_, key, value) => {
            const json = localStorage.getItem(name);
            let object = {};
            if (json) {
                object = JSON.parse(json);
                object[key] = value;
            }
            else
                object = { [key]: value };
            localStorage.setItem(name, JSON.stringify(object));
            return true;
        },
    });
};
export const vueAdapater = {
    state: {
        createState(name, state) {
            return (ctx) => {
                const useStore = stores[name] ??
                    defineStore(name, {
                        state: () => state(ctx),
                    });
                return createProxyStore(useStore);
            };
        },
        createPermState(name, state) {
            return () => createProxyPermStore(name);
        },
    },
};
